==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/it.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Sondaggio di utilizzo",
    "Last report sent on: {on}" : "Ultimo report inviato il: {on}",
    "An error occurred while sending your report." : "Si è verificato un errore durante l'invio del resoconto.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Elenco applicazioni <em>(per ogni applicazione: nome, versione, stato di abilitazione)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente del database <em>(tipo, versione, dimensione del database)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informazioni di cifratura <em>(è abilitata?, qual è il modulo predefinito)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Numero di condivisioni <em>(per tipo e permessi)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versione, limite di memoria, tempo di esecuzione max., dimensione dei file max.)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Dettagli istanza del server <em>(versione, memcache utilizzarta, stato di blocco/anteprime/avatar)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistiche <em>(numero di: file, utenti, archiviazioni per tipo, commenti e etichette)</em>",
    "Help improve Nextcloud" : "Aiutaci a migliorare Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vuoi aiutarci a migliorare Nextcloud fornendo alcuni dati resi anonimi relativi alla tua configurazione e utilizzo? Puoi disabilitare questa funzione in qualsiasi momento nelle impostazioni di amministrazione.",
    "Not now" : "Non ora",
    "Send usage" : "Invia utilizzo",
    "Never" : "Mai",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Invia dati anonimizzati a Nextcloud per aiutarci a migliorarlo.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Invia dati resi anonimi a Nextcloud per aiutarci a migliorare Nextcloud. Avrai\n        sempre il pieno controllo dei contenuti inviati a Nextcloud e puoi disabilitare\n        questa funzione in ogni momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Puoi contribuire a migliorare Nextcloud inviando alcuni dati sulla tua configurazione attuale e sull'utilizzo.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Siamo molto attenti alla tua riservatezza. L'invio di dati è disabilitato in modo predefinito e, se scegli di abilitarlo, saranno preventivamente resi anonimi. Hai la facoltà di scegliere cosa condividere. Dopo aver ricevuto un resoconto, il precedente viene rimosso. Carica un resoconto vuoto per eliminare tutti i dati attualmente memorizzati sul server",
    "Send new report now" : "Invia nuovo resoconto ora",
    "Send usage survey monthly" : "Invia mensilmente il sondaggio di utilizzo",
    "Data to send" : "Dati da inviare",
    "Last report sent on: %s" : "Ultimo report inviato il: %s",
    "Last report" : "Ultimo resoconto",
    "Sent on: {on}" : "Inviato il: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Elenco delle applicazioni <em>(per ogni applicazione: nome, versione, è abilitata?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Dettagli dell'istanza del server <em>(versione, memcache utilizzata, blocco/anteprime/avatar abilitati?)",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Puoi contribuire a migliorare Nextcloud inviando alcuni dati sulla tua configurazione attuale e sull'utilizzo.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Siamo molto attenti alla tua riservatezza. I dati sono resi anonimi e puoi abilitare/disabilitare l'invio in qualsiasi momento, è disabilitato in modo predefinito. Di seguito puoi regolare quale tipo di dati vengono inviati e vedere sempre l'ultimo resoconto inviatoci. Quando il server riceve un resoconto della tua istanza, tutte le voci del resoconto precedente sono rimosse. Nel caso in cui tu decida di disabilitare una delle impostazioni seguenti, puoi inviare un nuovo resoconto per eliminare i dati attualmente memorizzati sul server.",
    "Sent on: %s" : "Inviato il: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/it.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Sondaggio di utilizzo",
    "Last report sent on: {on}" : "Ultimo report inviato il: {on}",
    "An error occurred while sending your report." : "Si è verificato un errore durante l'invio del resoconto.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Elenco applicazioni <em>(per ogni applicazione: nome, versione, stato di abilitazione)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente del database <em>(tipo, versione, dimensione del database)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informazioni di cifratura <em>(è abilitata?, qual è il modulo predefinito)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Numero di condivisioni <em>(per tipo e permessi)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versione, limite di memoria, tempo di esecuzione max., dimensione dei file max.)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Dettagli istanza del server <em>(versione, memcache utilizzarta, stato di blocco/anteprime/avatar)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistiche <em>(numero di: file, utenti, archiviazioni per tipo, commenti e etichette)</em>",
    "Help improve Nextcloud" : "Aiutaci a migliorare Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vuoi aiutarci a migliorare Nextcloud fornendo alcuni dati resi anonimi relativi alla tua configurazione e utilizzo? Puoi disabilitare questa funzione in qualsiasi momento nelle impostazioni di amministrazione.",
    "Not now" : "Non ora",
    "Send usage" : "Invia utilizzo",
    "Never" : "Mai",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Invia dati anonimizzati a Nextcloud per aiutarci a migliorarlo.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Invia dati resi anonimi a Nextcloud per aiutarci a migliorare Nextcloud. Avrai\n        sempre il pieno controllo dei contenuti inviati a Nextcloud e puoi disabilitare\n        questa funzione in ogni momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Puoi contribuire a migliorare Nextcloud inviando alcuni dati sulla tua configurazione attuale e sull'utilizzo.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Siamo molto attenti alla tua riservatezza. L'invio di dati è disabilitato in modo predefinito e, se scegli di abilitarlo, saranno preventivamente resi anonimi. Hai la facoltà di scegliere cosa condividere. Dopo aver ricevuto un resoconto, il precedente viene rimosso. Carica un resoconto vuoto per eliminare tutti i dati attualmente memorizzati sul server",
    "Send new report now" : "Invia nuovo resoconto ora",
    "Send usage survey monthly" : "Invia mensilmente il sondaggio di utilizzo",
    "Data to send" : "Dati da inviare",
    "Last report sent on: %s" : "Ultimo report inviato il: %s",
    "Last report" : "Ultimo resoconto",
    "Sent on: {on}" : "Inviato il: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistiche <em>(numero di: file, utenti, archiviazioni per tipo, commenti e etichette)</em>",
    "Sent on: %s" : "Inviato il: %s"
},
"nplurals=2; plural=(n != 1);");
